@@ -14,6 +14,7 @@ from sqlalchemy.types import Text
 from base64 import b64decode
 
 from jinja2 import contextfunction
+from flask.ext.admin.contrib.sqla import form
 
 class ShelfModelView(sqla.ModelView):
     list_template = "shelf-admin/model/list.html"
@@ -29,7 +30,6 @@ class ShelfModelView(sqla.ModelView):
 
     def scaffold_form(self):
         cls = super(ShelfModelView, self).scaffold_form()
-        #print self.model
         for k, v in self.model.__dict__.items():
             if hasattr(v, "type") and isinstance(v.type, Text):
                 setattr(cls, k, WysiwygTextField())
@@ -44,6 +44,53 @@ class ShelfModelView(sqla.ModelView):
 
         return cls
 
+from flask.ext.admin.helpers import get_form_data
+
+class ShelfPageView(ShelfModelView):
+    can_create = False
+    can_delete = False
+    
+    def edit_form(self, obj=None):
+        """
+            Instantiate model editing form and return it.
+
+            Override to implement custom behavior.
+        """
+        converter = self.model_form_converter(self.session, self)
+        cls = form.get_form(obj.__class__, converter,
+                                   base_class=self.form_base_class,
+                                   only=self.form_columns,
+                                   exclude=self.form_excluded_columns,
+                                   field_args=self.form_args,
+                                   extra_fields=self.form_extra_fields)
+
+        if self.inline_models:
+            cls = self.scaffold_inline_form_models(form_class)
+
+        del cls.name
+
+        mapper = obj._sa_class_manager.mapper
+        properties = ((p.key, p) for p in mapper.iterate_properties)
+
+        for k, v in properties:
+            print k, v
+            if hasattr(v, "type") and isinstance(v.type, Text):
+                setattr(cls, k, WysiwygTextField())
+
+            if hasattr(v, "mapper"):
+                if issubclass(v.mapper.class_, shelf_computed_models()['LocalizedString']) \
+                    and not issubclass(obj.__class__, shelf_computed_models()['LocalizedString']):
+                        setattr(cls, k, LocalizedTextField())
+                elif issubclass(v.mapper.class_, shelf_computed_models()['LocalizedText']) \
+                    and not issubclass(obj.__class__, shelf_computed_models()['LocalizedText']):
+                        setattr(cls, k, LocalizedWysiwygTextField())
+
+        return cls(get_form_data(), obj=obj)
+
+    def update_model(self, form, model):
+        print form.data
+        return super(ShelfPageView, self).update_model(form, model)
+
 
 class ShelfFileAdmin(fileadmin.FileAdmin):
     list_template = "shelf-admin/file/list.html"
